@@ -1,8 +1,7 @@
 package Crypt::SecretBuffer::ConsoleState;
 # VERSION
-# ABSTRACT: Disable TTY echo within a scope
-$Crypt::SecretBuffer::ConsoleState::VERSION = '0.017_002'; # TRIAL
-$Crypt::SecretBuffer::ConsoleState::VERSION = '0.017002';
+# ABSTRACT: Disable TTY echo within a block scope
+$Crypt::SecretBuffer::ConsoleState::VERSION = '0.016';
 1;
 
 __END__
@@ -13,7 +12,7 @@ __END__
 
 =head1 NAME
 
-Crypt::SecretBuffer::ConsoleState - Disable TTY echo within a scope
+Crypt::SecretBuffer::ConsoleState - Disable TTY echo within a block scope
 
 =head1 DESCRIPTION
 
@@ -35,7 +34,6 @@ Options:
   handle        => $fh,
   auto_restore  => $bool
   echo          => $bool
-  line_input    => $bool
 
 =head2 maybe_new
 
@@ -46,7 +44,7 @@ Return a new object B<unless> the C<$handle> is not a console/tty, or if you req
 state and the console/tty is already in that state.  In other words, instead of writing
 
   my $st= eval { Crypt::SecretBuffer::ConsoleState->new($handle) };
-  if ($st && $st->echo) {
+  if ($st->echo) {
     $st->echo(0);
     $st->auto_restore(1);
   }
@@ -59,27 +57,18 @@ you can write
     echo => 0
   );
 
-and if it is not a tty or echo is already off, it returns C<undef> and skips the creation of
+and if it is not a tty or echo is already off, it returns C<$undef> and skips the creation of
 the object entirely.
 
 =head1 ATTRIBUTES
 
 =head2 auto_restore
 
-Automatically call C<restore> on object destruction, such as when it goes out of scope.
-Boolean, read/write.
+Automatically call C<restore> on object destruction (such as when it goes out of scope)
 
 =head2 echo
 
-Get or set the C<ECHO> flag on the console/tty.
-Boolean, read/write.
-
-=head2 line_input
-
-Get or set the line-buffering feature of the console/tty.  On Windows this is the
-C<ENABLE_LINE_INPUT> flag.  On Posix, this is the C<ICANON> flag, with the caveat that disabling
-it also enables the C<ISIG> flag so that the OS continues to handle C<^C> for you.
-Boolean, read/write.
+Get or set the ECHO flag on the console/tty.
 
 =head1 METHODS
 
@@ -89,7 +78,7 @@ Set the console/tty state to the original value seen when the object was created
 
 =head1 VERSION
 
-version 0.017_002
+version 0.016
 
 =head1 AUTHOR
 
@@ -97,7 +86,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Michael Conrad.
+This software is copyright (c) 2025 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
